@@ -8,7 +8,7 @@ eee   <- eigen(t(tpm))
 k <- match(1,round(eee$values,6))
 if(length(k) != 1) {
 	cat('Problems with eigenvalues:\n')
-	print(e.val)
+	print(eee$values)
 	stop()
 }
 ispd <- Re(eee$vectors[,k])
